@@ -12,13 +12,16 @@ apt-get update && apt-get install --no-install-recommends --no-install-suggests
     curl \
     git \
     lcov \
+    pkg-config \
+    libssl-dev \
     libgnutls28-dev \
     libgpgme-dev \
     libjson-glib-dev \
     libksba-dev \
     libpaho-mqtt-dev \
     libpcap-dev \
-    libssh-gcrypt-dev \
+    libgcrypt-dev \
+    libssh-dev \
     libbsd-dev \
     libgnutls30 \
     libgssapi3-heimdal \
